/*
* Copyright (c) 2014 Christian Surlykke
*
* This file is part of the Nde project. <https://lxqt.org>
* It is distributed under the LGPL 2.1 or later license.
* Please refer to the LICENSE file for a copy of the license.
*/

#include "batteryinfodialog.h"
#include "ui_batteryinfodialog.h"
#include "batteryhelper.h"
#include <Nde/Globals>
#include <kwindoweffects.h>
#include <QFormLayout>
#include <QTabWidget>
#include <QApplication>
#include <QDesktopWidget>
#include <QDebug>
#include <QCursor>
#include <QBitmap>
#include <QString>
#include <QPainter>
BatteryInfoDialog::BatteryInfoDialog(QList<Solid::Battery*> batteries, QWidget *parent) :
    QDialog(parent),
    ui(new Ui::BatteryInfoDialog)
{
    ui->setupUi(this);

    setWindowTitle(tr("Battery Info"));

    if (batteries.size() == 1)
    {
        BatteryInfoFrame *batteryInfoFrame = new BatteryInfoFrame(batteries[0]);
        ui->verticalLayout->insertWidget(0, batteryInfoFrame);
    }
    else
    {
        QTabWidget *tabWidget = new QTabWidget(this);
        ui->verticalLayout->insertWidget(0, tabWidget);
        for (Solid::Battery *const battery : qAsConst(batteries))
        {
            BatteryInfoFrame *batteryInfoFrame = new BatteryInfoFrame(battery);
            tabWidget->addTab(batteryInfoFrame, QSL("BAT"));
        }
    }
}

BatteryInfoDialog::~BatteryInfoDialog()
{
    delete ui;
}

void BatteryInfoDialog::toggleShow()
{
    qDebug() << "toggleShow";
    isVisible() ? hide() : show();
}

BatteryWidget::BatteryWidget(QList<Solid::Battery*> batteries,QWidget* parent)
    : QWidget(parent)
{
    battery = batteries;
    this->setWindowFlags(Qt::FramelessWindowHint |
                         Qt::Tool |
                         Qt::X11BypassWindowManagerHint);
    this->setAttribute(Qt::WA_TranslucentBackground);
    this->setAttribute(Qt::WA_NoSystemBackground, false);

    KWindowEffects::enableBlurBehind(this->winId(), true);
    setting = new Nde::Settings(QLatin1String("panel"),this);
    setting->beginGroup("panel1");
    setFixedSize(180,50);
    Init();

}
void BatteryWidget::paintEvent(QPaintEvent * event)
{
    QRect rect = this->rect().adjusted(0,0,-1,-1);
    QBitmap bmp(rect.size());
    bmp.fill();
    QPainter painter(&bmp);
    painter.setBrush(Qt::black);
    painter.setRenderHints(QPainter::HighQualityAntialiasing );
    painter.drawRoundedRect(bmp.rect(),3,3);
    setMask(bmp);

}
bool BatteryWidget::event(QEvent *e)
{
    if(e->type() == QEvent::ActivationChange)
    {
        if(!this->isActiveWindow())
        {
            this->hide();
        }
    }
    return QWidget::event(e);
}

void BatteryWidget::Init()
{
    QColor mBackgroundColor; //背景色
    icon =new QLabel();

    cout = new QLabel();
    //cout->setFixedWidth(50);
    cout->setStyleSheet("BatteryWidget QLabel{font-size:18px;color:rgb(255,255,255)}");
    cout->setAlignment(Qt::AlignLeft);
    msg = new QLabel();
    msg->setStyleSheet("BatteryWidget QLabel{font-size:14px;color:rgb(255,255,255)}");
    msg->setAlignment(Qt::AlignLeft);
    lay = new QHBoxLayout();

    lay->addSpacing(10);
    lay->addWidget(icon);
    lay->addSpacing(5);
    lay->addWidget(cout);
    lay->addSpacing(5);
    lay->addWidget(msg);
    lay->addStretch();
    setLayout(lay);
    updatebg();
}

void BatteryWidget::update()
{
    int ChargePercent = BatteryHelper::getBatteryChargecent();
    Solid::Battery::ChargeState state = BatteryHelper::getBatteryState();
    icon->setPixmap(icontool.genIcon(ChargePercent,state));
    cout->setText(QString::number(ChargePercent) + "%");
    //cout->setText(QString::number(100) + "%");
    if(state == Solid::Battery::Charging){
        msg->setText(tr("Charging"));
    } else if( state ==  Solid::Battery::Discharging){
        if (ChargePercent <= 20) {
            msg->setText(tr("Empty"));
        } else {
            msg->setText(tr("Battery"));
        }
    } else {
        msg->setText(tr("Battery"));
    }
}
void BatteryWidget::updatebg()
{
    QColor color = setting->value("background-color").value<QColor>();
    int opacity = setting->value("opacity").toInt();

    QString str;
    str = QString("%1,%2,%3,%4")
            .arg(color.red())
            .arg(color.green())
            .arg(color.blue())
            .arg(opacity/100.0);
    setStyleSheet(QString("BatteryWidget { background-color:rgba(" + str +");}"));

}
void BatteryWidget::toggleShow()
{
    activateWindow();
    update();
    QCursor cur;
    qInfo()<<cur.pos();
    QRect rect = QApplication::desktop()->screenGeometry();
    qInfo()<<rect;
    updatebg();
    QString position = setting->value("position").toString();
    int panelwidth =  setting->value("panelSize").toInt();
    qInfo()<<"panelwidth:"<<panelwidth;
    if(position.compare("Bottom") == 0) {
        move(cur.pos().x()-width()/2,rect.height()-panelwidth - height()-8);
    } else if (position.compare("Left") == 0) {
        move(panelwidth + 8,cur.pos().y()-height()/2);
    } else if (position.compare("Right") == 0) {
        move(rect.width()-panelwidth-width()-8,cur.pos().y()-height()/2);
    } else {
        move(cur.pos().x()-width()/2,panelwidth + 8);
    }
    isVisible() ? hide() : show();
}

