/*
* Copyright (c) 2014 Christian Surlykke
*
* This file is part of the Nde project. <https://lxqt.org>
* It is distributed under the LGPL 2.1 or later license.
* Please refer to the LICENSE file for a copy of the license.
*/

#ifndef ICONPRODUCER_H
#define ICONPRODUCER_H
#include <QString>
#include <QMap>
#include <QObject>
#include "../config/powermanagementsettings.h"
#include <Solid/Battery>
#include <QWidget>
#include <unordered_map>
#include <QIcon>
#include <QMutex>

class IconTool
{
public:
    IconTool();
    //从缓存获取图片
    QIcon GenIcon(int num,bool charging=false);
    QPixmap genIcon(int num,Solid::Battery::ChargeState = Solid::Battery::Discharging);
    //清除缓存
    void ClearCache();
private:
    //生成图片

    void drawBorder(QPainter *painter);
    void drawBg(QPainter *painter,int num);
    void drawHead(QPainter *painter);
    void drawflash(QPainter *painter);
private:

    //缓存的图片
    std::unordered_map<int,QIcon> ico_map;
    //锁
    QMutex mtx_;

    int width;
    int height;
    int border;
    int headwidth;
    int radius;
    QColor bdcolor;     //边框颜色
    QColor bgcolor;     //电量颜色
    QColor fhcolor;
};



class IconProducer : public QObject
{
    Q_OBJECT

public:
    IconProducer(Solid::Battery* battery, QObject *parent = 0);
    IconProducer(QObject *parent = 0);

    QIcon mIcon;
    QString mIconName;

signals:
    void iconChanged();

public slots:
    void updateChargePercent(int newChargePercent);
    void updateState(int newState);
    void update();
    void themeChanged();

private:
    IconTool icontool;
    QIcon &circleIcon();
    QIcon buildCircleIcon(Solid::Battery::ChargeState state, int chargeLevel);


    int mChargePercent;
    Solid::Battery::ChargeState mState;

    PowerManagementSettings mSettings;

    QMap<float, QString> mLevelNameMapCharging;
    QMap<float, QString> mLevelNameMapDischarging;

};

#endif // ICONPRODUCER_H
